@@ -49,11 +49,14 @@ from elluminate.schemas.template_variables import (
     TemplateVariables,
 )
 from elluminate.schemas.template_variables_collection import (
+    CollectionColumn,
+    ColumnTypeEnum,
     CreateCollectionRequest,
     TemplateVariablesCollection,
     TemplateVariablesCollectionFilter,
     TemplateVariablesCollectionSort,
     TemplateVariablesCollectionWithEntries,
+    UpdateCollectionRequest,
 )
 
 # Rebuild models to handle circular references.
@@ -70,6 +73,9 @@ __all__ = [
     "TemplateVariables",
     "TemplateVariablesCollection",
     "CreateCollectionRequest",
+    "UpdateCollectionRequest",
+    "CollectionColumn",
+    "ColumnTypeEnum",
     "TemplateVariablesCollectionFilter",
     "TemplateVariablesCollectionSort",
     "BatchCreatePromptResponseStatus",
